@@ -36,7 +36,7 @@ class TestJupyter(unittest.TestCase):
 
         mock_docker.build.assert_called_with(config, host=None, verbose=False)
         mock_docker.run.assert_called_with(
-            config, expectedCommand, "it", ["1127:8888"], ".", "jupyter", host=None, verbose=False
+            config, expectedCommand, "it", ["1127:8888"], ["."], "jupyter", host=None, verbose=False
         )
 
     @mock.patch('skelebot.components.jupyter.docker')
@@ -69,7 +69,24 @@ class TestJupyter(unittest.TestCase):
 
         mock_docker.build.assert_called_with(config, host="host1", verbose=False)
         mock_docker.run.assert_called_with(config, expectedCommand, "it", ["1127:8888"],
-            ".", "jupyter", host="host1", verbose=False
+            ["."], "jupyter", host="host1", verbose=False
+        )
+
+    @mock.patch('skelebot.components.jupyter.docker')
+    def test_execute_lab(self, mock_docker):
+        mock_docker.build.return_value = 0
+        config = sb.objects.config.Config(language="Python")
+        args = argparse.Namespace(verbose_global=False)
+
+        jupyter = sb.components.jupyter.Jupyter(port=1127, folder="notebooks/", mappings=["other_project/data"], lab=True)
+        jupyter.execute(config, args)
+
+        expectedCommand = "jupyter lab --ip=0.0.0.0 --port=8888 --allow-root --notebook-dir=notebooks/"
+
+        mock_docker.build.assert_called_with(config, host=None, verbose=False)
+        mock_docker.run.assert_called_with(
+            config, expectedCommand, "it", ["1127:8888"], [".", "other_project/data"],
+            "jupyter", host=None, verbose=False
         )
 
     def test_validate_valid(self):
